#
# spec file for package python-os-win
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global sname os-win
Name:           python-os-win
Version:        3.0.0
Release:        lp152.4.3
Summary:        Hyper-V library for OpenStack projects
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://launchpad.net/%{sname}
Source0:        https://files.pythonhosted.org/packages/source/o/%{sname}/%{sname}-%{version}.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python-Sphinx
BuildRequires:  python-ddt >= 1.0.1
BuildRequires:  python-devel
BuildRequires:  python-eventlet >= 0.18.2
BuildRequires:  python-mock >= 2.0.0
BuildRequires:  python-oslo.concurrency >= 3.25.0
BuildRequires:  python-oslo.i18n >= 3.15.3
BuildRequires:  python-oslo.log >= 3.36.0
BuildRequires:  python-oslosphinx >= 4.7.0
BuildRequires:  python-oslotest >= 3.2.0
BuildRequires:  python-pbr >= 2.0.0
BuildRequires:  python-python-subunit >= 1.0.0
BuildRequires:  python-testrepository >= 0.0.18
BuildRequires:  python-testscenarios >= 0.4
BuildRequires:  python-testtools >= 2.2.0
Requires:       python-Babel >= 2.3.4
Requires:       python-eventlet >= 0.18.2
Requires:       python-oslo.concurrency >= 3.25.0
Requires:       python-oslo.config >= 5.1.0
Requires:       python-oslo.i18n >= 3.15.3
Requires:       python-oslo.log >= 3.36.0
Requires:       python-oslo.service >= 1.24.0
Requires:       python-oslo.utils >= 3.33.0
Requires:       python-pbr >= 2.0.0
BuildArch:      noarch

%description
Library contains Windows / Hyper-V code commonly used in the OpenStack projects:
nova, cinder, networking-hyperv.

%package doc
Summary:        Documentation for OpenStack Windows/Hyper-V Library
Group:          Documentation/HTML
BuildRequires:  python-Sphinx
BuildRequires:  python-openstackdocstheme >= 1.18.1

%description doc
Documentation for the Hyper-V library.

%prep
%autosetup -n %{sname}-%{version}
%py_req_cleanup
# we dont want to run the hacking tests again (and dont want the needed deps)
rm -f os_win/tests/unit/test_hacking.py
sed -i 's/^warning-is-error.*/warning-is-error = 0/g' setup.cfg

%build
%{py2_build}
%{__python2} setup.py build_sphinx --builder=html,man
rm -rf html/.{doctrees,buildinfo}

%install
%{py2_install}
install -p -D -m 644 doc/build/man/os-win.1 %{buildroot}/%{_mandir}/man1/os-win.1

%check
%{__python2} setup.py test

%files
%doc README.rst ChangeLog
%license LICENSE
%{python2_sitelib}/os_win*
%{python2_sitelib}/*.egg-info
%{_mandir}/man1/os-win.1*

%files doc
%doc doc/build/html
%license LICENSE

%changelog
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 3.0.0
  - [Trivial] Add HyperVvSwitchNotFound exception
  - Implement VHD attach/detach
  - Remove setting of version/release from releasenotes
  - Add oslo.config entry point
  - Add config sample to os-win docs
  - doc: Switch to openstackdocstheme
  - Avoid tox_install.sh for constraints support
  - Adds SR-IOV support
  - Remove deprecated methods and exceptions
  - Updated from global requirements
  - Add processutils module
  - Cleanup vmutils create_vm
* Fri Nov 24 2017 cloud-devel@suse.de
- update to version 2.5.0
  - clusterutils: Adds clustering configuration options
  - Add method returning vswitch extensions
  - Include FCP lun when returning mappings
  - Add methods for retrieving disks
  - FC: cleanup WWN usage
  - FC: add support for retrieving FC LUN UIDs
  - check minimum VM version when setting VM snapshots
  - Update the documentation link for doc migration
  - Include disk ctrl addr in attachment info
  - Allow aggregating disk rescan requests
  - Allow detaching disks by serial tag
  - vmutils: Fixes setting disk QoS on Hyper-V 6.2
  - [Trivial] Add method checking if a disk is claimed by MPIO
  - Fix fetching vm boot sources
  - iSCSI: add checks for MPIO disks
  - Update log translation hacking rule
  - Adds releasenotes configuration
  - Updated from global requirements
  - Allow fetching disk attachment info by tag
  - Add SAN policy setter/getter
  - Silently continue when destroying missing vNIC
* Thu Sep 21 2017 cloud-devel@suse.de
- update to version 2.2.0
  - clusterutils: Adds clustering configuration options
  - Include FCP lun when returning mappings
  - Update UPPER_CONSTRAINTS_FILE for stable/pike
  - check minimum VM version when setting VM snapshots
  - FC: cleanup WWN usage
  - FC: add support for retrieving FC LUN UIDs
  - Allow detaching disks by serial tag
  - [Trivial] Add method checking if a disk is claimed by MPIO
  - iSCSI: add checks for MPIO disks
  - Update .gitreview for stable/pike
  - Adds releasenotes configuration
  - Add methods for retrieving disks
* Tue Sep 19 2017 cloud-devel@suse.de
- update to version 2.1.0
  - Add hacking rules for ctypes libraries
  - vmutils: Adds vnuma_enabled argument to update_vm
  - networkutils: fixes update_cache
  - removes the VirtualSystemType kwarg when fetching VMs
  - Fixed all typos in comments
  - Retry changing VM state in case of exceptions
  - Add cluster vm owner change listener
  - Fixes cached old WMI service objects issue
  - pathutils: Adds retry decorator to rmdir
  - Retrieve VM disk attachment info
  - Indicating the location tests directory in oslo_debug_helper
  - py35: fixes exception.message reference issues
  - Optimize the link address
  - vmutils: set all *DataRoot paths to the same value
  - Ignores "Not found" jobs when stopping jobs
  - Uses _compat_conn where WMI objects need to be updated or added
  - Change intermediary vm state handling
  - Replaces CRLF line endings to LF line endings
  - Remove old iSCSI initiator utils modules
  - Cleanup livemigrationutils
  - updates hacking requirement
  - pep8: fixes indentation issues
  - Add Python 3.5 classifier and venv
  - Rearrange imports
  - Remove deprecated IOUtils class
  - Improve WMI job check method
  - Fix cluster group migration status checks
  - Improve VM snapshots support
  - networkutils: specializes the exception raised by _get_vnic_settings
  - Allow setting VM snapshot types
  - tests: Sets baseutils.BaseUtilsVirt._old_wmi
  - Replacing six.iteritems() with .items()
  - Adds config option for caching WMI objects
  - Add support for setting the port profile id
  - raises exceptions.NotFound instead of x_wmi: Not Found
  - Ensure failed disk attachments are cleaned up
  - vmutils: Adds remove_all_pci_devices method
  - Fix share local address check
  - Remove log translations
  - Synchronize iscsi_target_utils
  - Add 'rm -f .testrepository/times.dbm' command in testenv
  - vmutils: Planned VMs separation
  - Refactor Windows API usage
  - pathutils: Adds copy_folder_files method
  - vmutils: Allows updating and disabling instance RemoteFX
  - Wrap "WMI not found" exception
  - Updated from global requirements
* Mon Mar 27 2017 cloud-devel@suse.de
- update to version 1.4.1:
  - vmutils: Adds vnuma_enabled argument to update_vm
  - vmutils: set all *DataRoot paths to the same value
  - removes the VirtualSystemType kwarg when fetching VMs
  - Update .gitreview for stable/ocata
  - Update UPPER_CONSTRAINTS_FILE for stable/ocata
  - pathutils: Adds retry decorator to rmdir
  - vmutils: Allows updating and disabling instance RemoteFX
  - vmutils: Adds remove_all_pci_devices method
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 1.4.0:
  - Non-clustered VM live migration fix
  - Removes all references to openstack.common
  - Move unit tests to a separate folder
  - Add methods for handling file ACLs
  - Allow setting automatic vm shutdown action
  - Implements qos methods in networkutils
  - Rename argument in iscsi_utils, breaking os-brick
  - Add method for retrieving vm config root dir
  - Add Constraints support
  - Ensure Win32 API calls do not block
  - vmutils: honor host argument
  - FibreChannel: ignore unsupported HBA adapters
  - Show team and repo badges on README
  - Changed author and author-email
  - Avoid opening parents when fetching VHD info
  - Removes unnecessary oslo.service requirement
  - Use assertEqual() instead of assertDictEqual()
  - Handle sporadic iSCSI initiator errors
  - Adds VLAN trunk mode support
  - Adds nested virtualization support
  - Fix iscsi volumes not being attached
  - Adds Hyper-V PCI Passthrough support
  - VM Importing/Exporting
  - Retry on opening named pipe failures
  - Fix clustered vm live migration
  - Ensure GetLastError gets called in the right thread
  - Pin docutils version
  - Add hbaapi path config option
  - use unpatched socket module to get addresses
  - Fix clustered VM migration status polling
  - Avoid using diskpart for disk rescans
  - Updated from global requirements
* Tue Nov 15 2016 dmueller@suse.com
- update to 1.2.1:
  * Ensure GetLastError gets called in the right thread
  * Retry on opening named pipe failures
  * Handle sporadic iSCSI initiator errors
  * Fix clustered VM migration status polling
  * VM Importing/Exporting
  * Non-clustered VM live migration fix
  * Fix clustered vm live migration
  * Add method for retrieving vm config root dir
  * vmutils: honor host argument
  * Avoid using diskpart for disk rescans
  * Ensure Win32 API calls do not block
  * Update .gitreview for stable/newton
* Thu Sep  1 2016 tbechtold@suse.com
- update to version 1.2.0
  * Remove discover from test-requirements
  * Resolves flake8 errors
  * Removes Windows Server 2008 R2 specific code
  * TrivialFix: Remove cfg import unused
  * Updates README.rst
  * Refactors wmi exceptions usage
  * Add public method for destroying planned vms
  * Fix DNS zone serial number retrieval
  * Adds docstrings to the public methods of hostutils and jobutils
  * TrivialFix: Remove logging import unused
  * Updated from global requirements
  * Retry failed disk rescans
  * Sets parent class for ISCSITargetUtils
* Wed Aug 10 2016 tbechtold@suse.com
- update to version 1.1.0
  * iSCSI tgt utils: remove workaround needed by old WMI lib
  * Hyper-V: Added checking secure VMs status
  * Adds method for returning DNS Zone properties
  * Add utils for managing DNS operations
  * Add instance job terminate timeout
  * Fix for VM's not getting IP due to missing SG rules
  * Properly handle stopping VM jobs
  * Updated from global requirements
* Mon Jul  4 2016 tbechtold@suse.com
- update to 1.0.0:
  * Fixes loading HGS namespace on early builds of Windows 10
  * Add method for checking whether a share is local
  * Fix disk rescan method
  * Fix event handle leaks
  * Hyper-V: Shielded VMs
  * Updated from global requirements
  * Fix iSCSI initiator utils docstring
  * iSCSI utils: accept rescan_attempts arg in login method
  * Add missing wmi to requirements.txt
  * Updated from global requirements
  * Add method for retrieving local share paths
  * Updated from global requirements
  * Events: use tpool only if thread module is patched
  * Fix event listeners
  * Updated from global requirements
  * Adds missing attribute from get_cpus_info query
  * Fix retrieving VM notes race condition
  * Fix retrieving VHDX block size
  * Updated from global requirements
  * Fix retrieving VM physical disk mapping
  * Copies get_share_capacity_info to diskutils
  * python3: Fixes vhdutils internal VHDX size
  * Consistently raise exception if port not found
  * Ensure vmutils honors the host argument
  * Sets OsWinBaseTestCase as base class for unit tests
  * Fixes PyMI compatiblity issue
  * Fixes vmutils take_vm_snapshot method
  * Adds check for VLAN and VSID operations
  * Fix named pipe handler cleanup regression
  * Fixes vmutils get_vm_generation method
  * Improve clusterutils with new pyMI features
  * Ensure namedpipe IO workers clean up handles when stopping
  * switch to post-versioning
  * Bump version to 0.3.3
  * Deprecate volumeutils v1
  * Instance event listener: ignore exceptions
  * Replace associators with direct queries (part 2)
  * Fix serial console worker blocking Nova
  * Adds Hyper-V Cluster related utils
  * Fixed _winreg OpenKey parameter
  * Bump version to 0.3.2
- Use .spec from upstream rpm-packaging project
- Use renderspec source service to update .spec
* Wed Mar 30 2016 dmueller@suse.com
- fix license
* Mon Mar 14 2016 tbechtold@suse.com
- Update Requires
* Mon Mar 14 2016 tbechtold@suse.com
- Initial packaging (version 0.3.1)
